import { LabIcon } from '@jupyterlab/ui-components';
import { DisposableDelegate } from '@lumino/disposable';
import { ToolbarButton } from '@jupyterlab/apputils';
class Button {
    constructor(config) {
        this._icon = config.icon;
        if (config.onClick) {
            this._onClick = config.onClick;
        }
        else {
            this._onClick = () => { };
        }
        this._rank = config.rank;
        this._name = config.name;
        this._tooltip = config.tooltip ? config.tooltip : '';
        this._label = config.label ? config.label : '';
    }
    /**
     * Create a new extension for the notebook panel widget.
     *
     * @param panel Notebook panel
     * @param context Notebook context
     * @returns Disposable on the added button
     */
    createNew(panel, context) {
        const button = new ToolbarButton({
            className: 'mutable-ai-prod',
            icon: this._icon,
            label: this._label,
            onClick: () => this._onClick(context),
            tooltip: this._tooltip
        });
        panel.toolbar.insertItem(this._rank, this._name, button);
        return new DisposableDelegate(() => {
            button.dispose();
        });
    }
    _onClick(context) { }
}
export class MutableAIButtonFactory {
    constructor(config) {
        this._docRegistry = config.docRegistry;
        if (config.onLunchToProduction) {
            const icon = new LabIcon({
                name: 'ui-components:mutable-prod',
                svgstr: `<svg viewBox="0 0 512 512" height="48" width="48" focusable="false" role="img" fill="#00000087" xmlns="http://www.w3.org/2000/svg" class="StyledIconBase-ea9ulj-0 bWRyML"><title>Rocket icon</title><path d="M477.64 38.26a4.75 4.75 0 00-3.55-3.66c-58.57-14.32-193.9 36.71-267.22 110a317 317 0 00-35.63 42.1c-22.61-2-45.22-.33-64.49 8.07C52.38 218.7 36.55 281.14 32.14 308a9.64 9.64 0 0010.55 11.2l87.31-9.63a194.1 194.1 0 001.19 19.7 19.53 19.53 0 005.7 12L170.7 375a19.59 19.59 0 0012 5.7 193.53 193.53 0 0019.59 1.19l-9.58 87.2a9.65 9.65 0 0011.2 10.55c26.81-4.3 89.36-20.13 113.15-74.5 8.4-19.27 10.12-41.77 8.18-64.27a317.66 317.66 0 0042.21-35.64C441 232.05 491.74 99.74 477.64 38.26zM294.07 217.93a48 48 0 1167.86 0 47.95 47.95 0 01-67.86 0z"></path><path d="M168.4 399.43c-5.48 5.49-14.27 7.63-24.85 9.46-23.77 4.05-44.76-16.49-40.49-40.52 1.63-9.11 6.45-21.88 9.45-24.88a4.37 4.37 0 00-3.65-7.45 60 60 0 00-35.13 17.12C50.22 376.69 48 464 48 464s87.36-2.22 110.87-25.75A59.69 59.69 0 00176 403.09c.37-4.18-4.72-6.67-7.6-3.66z"></path></svg>`
            });
            const buttonConfig = {
                icon,
                onClick: config.onLunchToProduction,
                rank: 10,
                name: 'prod-button',
                label: '',
                tooltip: 'Fast forward to production.'
            };
            this._launchToProduction = new Button(buttonConfig);
        }
        if (config.onDocToProduction) {
            const icon = new LabIcon({
                name: 'ui-components:mutable-doc',
                svgstr: `<svg viewBox="0 0 48 48" height="48" width="48" focusable="false" role="img" fill="#00000087" xmlns="http://www.w3.org/2000/svg" class="StyledIconBase-ea9ulj-0 bWRyML"><title>Document icon</title><path d="M24 4v11.25A3.75 3.75 0 0 0 27.75 19H40v21a3 3 0 0 1-3 3H11a3 3 0 0 1-3-3V7a3 3 0 0 1 3-3h13z"></path><path d="M26.5 4.46v10.79c0 .69.56 1.25 1.25 1.25h11.71L26.5 4.46z"></path></svg>`
            });
            const buttonConfig = {
                icon,
                onClick: config.onDocToProduction,
                rank: 11,
                name: 'doc-button',
                label: '',
                tooltip: 'Fast forward to production documentation.'
            };
            this._docToProduction = new Button(buttonConfig);
        }
    }
    initialize() {
        if (this._launchToProduction) {
            this._docRegistry.addWidgetExtension('Notebook', this._launchToProduction);
        }
        if (this._docToProduction) {
            this._docRegistry.addWidgetExtension('Notebook', this._docToProduction);
        }
    }
}
